@@ -12,9 +12,9 @@ target = /tmp/
 
 import os
 
-from sprinter.formulabase import FormulaBase
-from sprinter.exceptions import ExtractException
-from sprinter.directory import DirectoryException
+from sprinter.formula.base import FormulaBase
+from sprinter.lib import ExtractException, system
+from sprinter.core.directory import DirectoryException
 import sprinter.lib as lib
 
 
@@ -86,7 +86,7 @@ class UnpackFormula(FormulaBase):
                                 remove_common_prefix=remove_common_prefix)
 
             elif config.get('type', config.get('url')).endswith("dmg"):
-                if not self.system.isOSX():
+                if not system.is_osx():
                     self.logger.warn("Non OSX based distributions can not install a dmg!")
                 else:
                     lib.extract_dmg(config.get('url'), destination,
